/*
	(C) 1995-97 AROS - The Amiga Research OS
	$Id: easyrequestargs.c,v 1.2 2009/01/02 11:40:03 jacadcaps Exp $
 
	Desc: Intuition function EasyRequestArgs()
	Lang: english
*/

#include "intuition_intern.h"
#ifdef MUIREQS
#include "mui_requesters.h"
#include "libraries/mui.h"
#endif

/*****************************************************************************
 
	NAME */
#include <exec/types.h>
#include <intuition/intuition.h>
#include <proto/intuition.h>

AROS_LH4(LONG, EasyRequestArgs,

		 /*  SYNOPSIS */
		 AROS_LHA(struct Window     *, window, A0),
		 AROS_LHA(struct EasyStruct *, easyStruct, A1),
		 AROS_LHA(ULONG             *, IDCMP_ptr, A2),
		 AROS_LHA(APTR               , argList, A3),

		 /*  LOCATION */
		 struct IntuitionBase *, IntuitionBase, 98, Intuition)

/*  FUNCTION
	Opens and handles a requester, which provides one or more choices.
	It blocks the application until the user closes the requester.
	Returned is a integer indicating which gadget had been selected.
 
	INPUTS
	Window - A reference window. If NULL, the requester opens on
		 the default public screen.
	easyStruct - The EasyStruct structure (<intuition/intuition.h>),
		     which describes the requester.
	IDCMP_Ptr - Pointer to IDCMP flags, which satisfy the requester,
		    too. This is useful for requesters, which want to
		    listen to disk changes, etc. The contents of this
		    pointer is set to the IDCMP flag, which caused the
		    requester to close. This pointer may be NULL.
	ArgList - The arguments for easyStruct->es_TextFormat.
 
	RESULT
	-1, if one of the IDCMP flags of idcmpPTR was set.
	 0, if the rightmost button was clicked or an error occured.
	 n, if the n-th button from the left was clicked.
 
	NOTES
 
	EXAMPLE
 
	BUGS
 
	SEE ALSO
	BuildEasyRequestArgs()
 
	INTERNALS
 
	HISTORY
	29-10-95    digulla automatically created from
			    intuition_lib.fd and clib/intuition_protos.h
 
*****************************************************************************/
{
	AROS_LIBFUNC_INIT
	AROS_LIBBASE_EXT_DECL(struct IntuitionBase *,IntuitionBase)

	struct IntRequestUserData *udata;
	struct Window *req;
	LONG result = -2;

	req = BuildEasyRequestArgs(window, easyStruct,
	                           IDCMP_ptr != NULL ? *IDCMP_ptr : NULL, argList);

	if (req && req != (struct Window *)1)
	{
		udata = IW(req)->requserdata;

		if (udata->classicrequester)
		{
			while ((result = SysReqHandler(req, IDCMP_ptr, TRUE)) == -2)
			{}
		}
		else
		{
			result = mui_reqhandler(req,IDCMP_ptr,IntuitionBase);
		}
	}

	FreeSysRequest(req);

	return result;
	AROS_LIBFUNC_EXIT
} /* EasyRequestArgs */

